Module event
certsd
0.6.14
Module event
Module Items
Structs
In crate certsd
certsd
Module
event
Events represent single points in time during the execution of a program.
Structs

Event
Event
s represent single points in time where something occurred during the execution of a program.